import * as React from "react";
export declare type Responsiveness = "tablet" | "phone" | "both" | "none";
export declare type Color = "positive" | "negative" | "warning" | "info" | "brand";
export declare type Size = "none" | "xxsmall" | "xsmall" | "small" | "medium" | "large" | "xlarge";
export declare type Side = "top" | "left" | "right" | "bottom" | "all";
export declare type CenterContentVertical = "top" | "center" | "bottom";
export declare type CenterContentHorizontal = "left" | "center" | "right";
export declare type CenterBoth = "both";
export interface CenterContent {
    vertical?: CenterContentVertical;
    horizontal?: CenterContentHorizontal;
}
export interface Spacing {
    top?: Size;
    bottom?: Size;
    left?: Size;
    right?: Size;
}
export interface Background {
    color?: Color;
    url?: string;
}
export interface Foreground {
    color?: Color;
    textAlignment?: string;
}
export declare enum SpacingType {
    Padding = 0,
    Margin = 1,
}
export declare enum ColorType {
    Foreground = 0,
    Background = 1,
}
export interface DisplayProps {
    background?: Background;
    foreground?: Foreground | string;
}
export interface LayoutProps {
    margin?: Spacing | Size;
    padding?: Spacing | Size;
    textAlignment?: CenterContentHorizontal;
}
export declare class LayoutHelpers {
    static GetBackgroundImage(background: Background): React.CSSProperties;
    static HandleLayoutClasses(margins?: Spacing | Size, paddings?: Spacing | Size, contentCentering?: CenterContent | CenterBoth, textAlignment?: CenterContentHorizontal): string;
    static HandleResponsivenessClasses(responsiveness?: Responsiveness): string;
    static HandleDisplayClasses(background?: Background, foreground?: Foreground): string;
    static HandleDisplayStyles(background?: Background, foreground?: Foreground): React.CSSProperties;
    static GetMargin(margins: Spacing | Size): string;
    static GetPadding(paddings: Spacing | Size): string;
    static GetTextAlignment(textAlignment: CenterContentHorizontal): string;
    static GetAlignment(centerContent: CenterContent | CenterBoth): string;
    static GetHorizontalAlignment(alignment: CenterContentHorizontal): string;
    static GetVerticalAlignment(alignment: CenterContentVertical): string;
    static GetSpacings(spacing: Spacing | Size, spacingType: SpacingType): string;
    static GetColorClass(color: Color, colorType: ColorType): string;
    static GetSpacingClass(size: Size, side: Side, type: SpacingType): string;
}
